using ResourcesManager.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace ResourcesManager.ViewModels
{
    public class StatisticViewModel
    {
        public List<ByType> ByType { get; set; }
        public List<ByResource> ByResource { get; set; }
        public List<ByTypeCircle> ByTypeCircle { get; set; }
        public List<Subscribe> Subscribe { get; set; }
        public SelectList Resources { get; set; }
        public SelectList StatisticType { get; set; }
    }
    public class ByType
    {
        public DateTime Name { get; set; }
        public int Value { get; set; }
    }
    public class ByResource
    {
        public DateTime Name { get; set; }
        public int Value { get; set; }
    }
    public class ByTypeCircle
    {
        public string Name { get; set; }
        public int Value { get; set; }
    }
    public class Subscribe
    {
        public string Name { get; set; }
        public int Value { get; set; }
    }
}